
-- This file specifies which prototypes should not be altered when other mods are loaded in order to remain compatible with them.

-- Create squeak_through_exclusions table if it has not already been created by another mod.
if not squeak_through_exclusions then squeak_through_exclusions = {} end


-- UraniumPower mod    (some test-entities display errors if altered so are excluded below)
squeak_through_exclusions["UraniumPower"] = squeak_through_exclusions["UraniumPower"] or  -- Use mod added exclusions instead if they exist.
{
	-- Only exclude these prototypes when this mod added object is detected.
	apply_when_object_exists = 
	{
		type = "storage-tank",
		name = "lube-port"
	},
	-- Individual prototypes names to not alter.
	excluded_prototype_names = 
	{
		"lube-port",
		"fluid-box-1",
		"fluid-box-2"
	}
}


-- RailTanker mod needs vanilla sized pumps (RailTanker version 1.1.3 and later includes compatibility for squeak through).
squeak_through_exclusions["RailTanker"] = squeak_through_exclusions["RailTanker"] or  -- Use mod added exclusions instead if they exist.
{
	-- Only exclude these prototypes when this mod added object is detected.
	apply_when_object_exists = 
	{
		type = "cargo-wagon",
		name = "rail-tanker"
	},
	-- Types of prototypes to not alter (affects prototypes from all mods).
	excluded_prototype_types = 
	{
		"pump"
	}
}


-- This is just for testing Squeak Through compatibility stuff is overridden properly when mods add it themselves.
--    Note: The name typo is intentional - it's to make the mod load before Squeak Through does.
squeak_through_exclusions["Squeaka Through Compatibility Test"] = squeak_through_exclusions["Squeaka Through Compatibility Test"] or  -- Use mod added exclusions instead if they exist.
{
	-- Only exclude these prototypes when this mod added object is detected.
	apply_when_object_exists = 
	{
		type = "container",
		name = "test-iron-chest"
	},
	-- Individual prototypes names to not alter. (string array)
	excluded_prototype_names = 
	{
		"test-iron-chest"
	},
	-- Types of prototypes to not alter (affects prototypes from all mods).
	excluded_prototype_types = 
	{
		"pipe"
	}
}


-- Uncomment the line below to check that this is being run - you should see an error pop up when the game loads containing these exclusions.
-- error("squeak_through_exclusions:" .. serpent.block(squeak_through_exclusions) )


--[[  Exclusion syntax:   Defines which prototypes squeak though should not alter for mod compatibility.
	
		apply_when_object_exists (optional):   Exclusions will only be applied when an object of the specified type and name is found ( in data.raw[type][name] ).
		                                       If omitted the exclusions will always be applied.
			type                                Note: The type and name code can be copied directly from the prototype definition in the mod to here.
			name
		
		excluded_prototype_names (optional):   (string array) Individual prototypes which should not be altered e.g "small-pump" or "steam-engine".
		
		excluded_prototype_types (optional):   (string array) Types of prototypes which should not be altered e.g "pump" or "generator".
		                                       All prototypes from all mods of the types specified will be excluded from alteration. 
		                                       Meaning if you exclude "pump" no pumps will have their collision boxes changed.
--]]


-- FYI:  The squeak_through_exclusions table will be parsed in Squeak Through when it runs (after all mods data.lua and data-updates.lua have executed).
--       It is visible to other mods because all data-related scripts are run in a shared lua interpreter. https://wiki.factorio.com/index.php?title=Lua/Data_Lifecycle
--       Remote interfaces are not available at this point as remote is undefined.
--
--       The reason for specifying the mod name to allow any compatibility stuff defined in Squeak Through to be overridden by other mods whenever they are updated.

